@@ -2,6 +2,7 @@ import sys
 import argparse
 import traceback
 import tl.exceptions
+from tl.utility.logging import Logger
 
 
 def parser():
@@ -21,7 +22,7 @@ def add_arguments(parser):
                         help='column name with ranking scores')
 
     parser.add_argument('-k', action='store', type=int, dest='k', default=1,
-                        help='calculate recall at top k, default is 1')
+                        help='calculate recall at top k, can send multiple values in one time, default is 1')
 
     parser.add_argument('--tag', action='store', type=str, dest='tag', default='',
                         help='a tag to use in the output file to identify the results of running the given pipeline')
@@ -32,10 +33,17 @@ def add_arguments(parser):
 def run(**kwargs):
     from tl.evaluation import evaluation
     import pandas as pd
+    import time
     try:
         df = pd.read_csv(kwargs['input_file'], dtype=object)
-
+        start = time.time()
         odf = evaluation.metrics(kwargs['column'], k=kwargs['k'], df=df, tag=kwargs['tag'])
+        end = time.time()
+        logger = Logger(kwargs["logfile"])
+        logger.write_to_file(args={
+            "command": "metrics",
+            "time": end-start
+        })
         odf.to_csv(sys.stdout, index=False)
     except:
         message = 'Command: metrics\n'
